CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
86 lines
2.1 KiB
C++
86 lines
2.1 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
#include <utils.hh>
|
|
/**
|
|
* @addtogroup hipEventQuery hipEventQuery
|
|
* @{
|
|
* @ingroup EventTest
|
|
* `hipEventQuery(hipEvent_t event)` -
|
|
* Query the status of the specified event.
|
|
* ________________________
|
|
* Test cases from other modules:
|
|
* - @ref Unit_hipEventIpc
|
|
*/
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Query events with a single and with multiple devices.
|
|
* Test source
|
|
* ------------------------
|
|
* - unit/event/Unit_hipEventQuery.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 5.2
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipEventQuery_DifferentDevice) {
|
|
hipEvent_t event1{}, event2{};
|
|
HIP_CHECK(hipEventCreate(&event1));
|
|
HIP_CHECK(hipEventCreate(&event2));
|
|
REQUIRE(event1 != nullptr);
|
|
REQUIRE(event2 != nullptr);
|
|
|
|
hipStream_t stream{nullptr};
|
|
HIP_CHECK(hipStreamCreate(&stream));
|
|
REQUIRE(stream != nullptr);
|
|
|
|
{
|
|
HIP_CHECK(hipSetDevice(0));
|
|
HIP_CHECK(hipEventRecord(event1, stream));
|
|
LaunchDelayKernel(std::chrono::milliseconds(isQuickLevel() ? 100 : 3000), stream);
|
|
HIP_CHECK(hipEventRecord(event2, stream));
|
|
|
|
HIP_CHECK(hipEventSynchronize(event1));
|
|
HIP_CHECK(hipEventQuery(event1)); // Should be done
|
|
|
|
HIP_CHECK_ERROR(hipEventQuery(event2),
|
|
hipErrorNotReady); // Wont be done since stream is blocked
|
|
}
|
|
|
|
// If other devices are available, set it
|
|
if (HipTest::getDeviceCount() > 1) {
|
|
HIP_CHECK(hipSetDevice(1));
|
|
}
|
|
|
|
// Query from same or other device depending on availability
|
|
{
|
|
HIP_CHECK(hipEventQuery(event1));
|
|
HIP_CHECK_ERROR(hipEventQuery(event2), hipErrorNotReady);
|
|
|
|
HIP_CHECK(hipEventSynchronize(event2));
|
|
|
|
// Query, should be done now
|
|
HIP_CHECK(hipEventQuery(event2));
|
|
}
|
|
|
|
// Query on same device if multiple devices are present
|
|
if (HipTest::getDeviceCount() > 1) {
|
|
HIP_CHECK(hipSetDevice(0));
|
|
HIP_CHECK(hipEventQuery(event2));
|
|
}
|
|
|
|
HIP_CHECK(hipEventDestroy(event1));
|
|
HIP_CHECK(hipEventDestroy(event2));
|
|
HIP_CHECK(hipStreamDestroy(stream));
|
|
}
|
|
|
|
/**
|
|
* End doxygen group EventTest.
|
|
* @}
|
|
*/
|